@@ -17,8 +17,7 @@ def index_variation(cursor):
                                num_hom_alt, num_unknown)''')
     cursor.execute('''create index var_aaf_idx on variants(aaf)''')
     cursor.execute('''create index var_in_dbsnp_idx on variants(in_dbsnp)''')
-    cursor.execute('''create index var_in_call_rate_idx on \
-                      variants(call_rate)''')
+    cursor.execute('''create index var_in_call_rate_idx on variants(call_rate)''')
     cursor.execute('''create index var_exonic_idx on variants(is_exonic)''')
     cursor.execute('''create index var_coding_idx on variants(is_coding)''')
     cursor.execute('''create index var_lof_idx on variants(is_lof)''')
@@ -35,7 +34,9 @@ def index_variation(cursor):
     cursor.execute('''create index var_homalt_idx on variants(num_hom_alt)''')
     cursor.execute('''create index var_het_idx on variants(num_het)''')
     cursor.execute('''create index var_unk_idx on variants(num_unknown)''')
-    cursor.execute('''create index var_callrate_idx on variants(call_rate)''')
+    cursor.execute('''create index var_omim_idx on variants(in_omim)''')
+    cursor.execute('''create index var_cadd_raw_idx on variants(cadd_raw)''')
+    cursor.execute('''create index var_cadd_scaled_idx on variants(cadd_scaled)''')
 
 
 def index_variation_impacts(cursor):
@@ -150,6 +151,7 @@ def create_tables(cursor):
                     aa_length text,                             \
                     biotype text,                               \
                     impact text default NULL,                   \
+                    impact_so text default NULL,                \
                     impact_severity text,                       \
                     polyphen_pred text,                         \
                     polyphen_score float,                       \
@@ -199,7 +201,9 @@ def create_tables(cursor):
                     encode_consensus_k562 text,                 \
                     vista_enhancers text,                       \
                     cosmic_ids text,                            \
-                    info blob,                           \
+                    info blob,                                  \
+                    cadd_raw float,                             \
+                    cadd_scaled float,                          \
                     PRIMARY KEY(variant_id ASC))''')
 
     cursor.execute('''create table if not exists variant_impacts  (   \
@@ -216,6 +220,7 @@ def create_tables(cursor):
                     aa_length text,                                   \
                     biotype text,                                     \
                     impact text,                                      \
+                    impact_so text,                                   \
                     impact_severity text,                             \
                     polyphen_pred text,                               \
                     polyphen_score float,                             \
@@ -253,6 +258,7 @@ def create_tables(cursor):
                    transcript_status text,                             \
                    ccds_id text,                                       \
                    hgnc_id text,                                       \
+                   entrez_id text,                                     \
                    cds_length text,                                    \
                    protein_length text,                                \
                    transcript_start text,                              \
@@ -260,6 +266,7 @@ def create_tables(cursor):
                    strand text,                                        \
                    synonym text,                                       \
                    rvis_pct float,                                     \
+                   mam_phenotype_id text,                              \
                    PRIMARY KEY(uid ASC))''')
                    
     cursor.execute('''create table if not exists gene_summary (     \
@@ -274,6 +281,7 @@ def create_tables(cursor):
                     strand text,                                    \
                     synonym text,                                   \
                     rvis_pct float,                                 \
+                    mam_phenotype_id text,                          \
                     in_cosmic_census bool,                          \
                     PRIMARY KEY(uid ASC))''')
 
@@ -303,7 +311,8 @@ def _insert_variation_one_per_transaction(cursor, buffer):
                                                              ?,?,?,?,?,?,?,?,?,?, \
                                                              ?,?,?,?,?,?,?,?,?,?, \
                                                              ?,?,?,?,?,?,?,?,?,?, \
-                                                             ?,?,?,?,?,?,?,?,?,?,?)', variant)
+                                                             ?,?,?,?,?,?,?,?,?,?, \
+                                                             ?,?,?,?)', variant)
             cursor.execute("END TRANSACTION")
         # skip repeated keys until we get to the failed variant
         except sqlite3.IntegrityError, e:
@@ -330,7 +339,8 @@ def insert_variation(cursor, buffer):
                                                          ?,?,?,?,?,?,?,?,?,?, \
                                                          ?,?,?,?,?,?,?,?,?,?, \
                                                          ?,?,?,?,?,?,?,?,?,?, \
-                                                         ?,?,?,?,?,?,?,?,?,?,?)', buffer)
+                                                         ?,?,?,?,?,?,?,?,?,?, \
+                                                         ?,?,?,?)', buffer)
 
         cursor.execute("END TRANSACTION")
     except sqlite3.ProgrammingError:
@@ -345,7 +355,7 @@ def insert_variation_impacts(cursor, buffer):
     cursor.execute("BEGIN TRANSACTION")
     cursor.executemany('insert into variant_impacts values (?,?,?,?,?,?,?,?, \
                                                             ?,?,?,?,?,?,?,?, \
-                                                            ?,?)',
+                                                            ?,?,?)',
                        buffer)
     cursor.execute("END")
 
@@ -364,7 +374,8 @@ def insert_sample(cursor, sample_list):
 def insert_gene_detailed(cursor, table_contents):
     cursor.execute("BEGIN TRANSACTION")
     cursor.executemany('insert into gene_detailed values (?,?,?,?,?,?,?,?,?, \
-                                                          ?,?,?,?,?,?,?,?)',
+                                                          ?,?,?,?,?,?,?,?,?, \
+                                                          ?)',
                         table_contents)
     cursor.execute("END")
     
@@ -372,7 +383,7 @@ def insert_gene_detailed(cursor, table_contents):
 def insert_gene_summary(cursor, contents):
     cursor.execute("BEGIN TRANSACTION")
     cursor.executemany('insert into gene_summary values (?,?,?,?,?,?,?,?, \
-                                                         ?,?,?,?)', 
+                                                         ?,?,?,?,?)', 
                         contents)
     cursor.execute("END")
     
